@@ -32,11 +32,16 @@ HD_DEFINE_PLUGIN_MODULE (QuickLaunchStatusMenuItem, quick_launch_status_menu_ite
 
 
 
-static void
+void
 parse_info (GConfClient* client)
 {
+	g_print("parsing info\n");
+	if ( client == NULL )
+		g_print("clnt null\n");
+	else g_print("clnt ok'\n");
 	GError *err;
 	GtkWidget *icoim;
+	GdkPixbuf *pixim;
 	int i;
 	GSList *lst = NULL;
 	gpointer *in;
@@ -46,11 +51,35 @@ parse_info (GConfClient* client)
 			lst = gconf_client_get_list (GCONF_CLIENT(client),g_strdup_printf("%s%s",APP_GCONF_KEY,group_name[i]), GCONF_VALUE_STRING, &err);
 			if ( lst != NULL ) {
 				in = g_slist_nth_data (lst, 1);
+				/*
+				 *  gdk_pixbuf_scale_simple         (const GdkPixbuf *src,
+				 *                                               int dest_width,
+				 *                                                                                            int dest_height,
+				 *                                                                                                                                         GdkInterpType interp_type);
+				 *
+				 *
+				 *
+				 * GdkPixbuf*  gdk_pixbuf_new_from_file        (const char *filename,
+				 *                                              GError **error);
+				 *
+				 *                                              
 				icoim = gtk_image_new_from_file( (gchar *)in );
+				gtk_widget_set_usize ( GTK_WIDGET(icoim), 48,48 );
+				
+				*/
+				g_print("getted = %s\n",in);
+				pixim = gdk_pixbuf_new_from_file ( (gchar *)in, NULL );
+				icoim = gtk_image_new_from_pixbuf (gdk_pixbuf_scale_simple ( pixim, 48,48, GDK_INTERP_BILINEAR ));
+//				gtk_widget_set_usize ( GTK_WIDGET(icoim), 48,48 );
+				
+				if ( btns[i] == NULL )
+					g_print("btn failsk\n");
+				else g_print("btn ok'\n");
 				hildon_button_set_image ( HILDON_BUTTON(btns[i]), icoim );
-				hildon_button_set_image_position (HILDON_BUTTON(btns[i]), GTK_POS_LEFT);
-				hildon_button_set_alignment (HILDON_BUTTON(btns[i]), 0.0, 0.0, 1.0, 1.0);
-				hildon_button_set_image_alignment (HILDON_BUTTON(btns[i]), 0.0, 0.0);
+				gtk_widget_show ( GTK_WIDGET(btns[i]) );
+//				hildon_button_set_image_position (HILDON_BUTTON(btns[i]), GTK_POS_LEFT);
+//				hildon_button_set_alignment (HILDON_BUTTON(btns[i]), 0.0, 0.0, 0.0, 0.0);
+//				hildon_button_set_image_alignment (HILDON_BUTTON(btns[i]), 0.0, 0.0);
 //				hildon_button_set_image_position (HILDON_BUTTON(btns[i]), GTK_POS_LEFT);
 
 			}
@@ -60,7 +89,7 @@ parse_info (GConfClient* client)
 }
 
 
-static gboolean
+gboolean
 load_app(GtkWidget *widget , gpointer data)
 {
 	gint pos;
@@ -88,6 +117,7 @@ load_app(GtkWidget *widget , gpointer data)
 			oss = (gchar *)o;
 			cbin = (gchar *)b;
 			
+			if ( GTK_IS_WIDGET(d) ) gtk_widget_destroy( GTK_WIDGET(d) );
 			if ( g_strcasecmp(oss,"")!=0 ) {
 				gboolean result;
 			
@@ -150,7 +180,8 @@ quick_launch_status_menu_item_init (QuickLaunchStatusMenuItem *plugin)
    	hbox = gtk_hbox_new(FALSE, 0);
    	int i;
    	for(i=0;i<4;i++) {
-	   	btns[i] = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+	   	btns[i] = hildon_button_new(HILDON_SIZE_THUMB_HEIGHT,
+				/*HILDON_SIZE_FINGER_HEIGHT,*/ HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 	   	gtk_widget_set_size_request ( GTK_WIDGET(btns[i]), 64,64 );
 		gtk_widget_show(btns[i]);
 		gtk_box_pack_start(GTK_BOX(hbox), btns[i], TRUE, TRUE, 1);
